//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/PlotComparison/HistogramPlot.cpp
//! @brief     Implements class HistogramPlot
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/PlotComparison/HistogramPlot.h"
#include "GUI/View/PlotUtil/PlotConstants.h"
#include <qcustomplot.h>

HistogramPlot::HistogramPlot(QWidget* parent)
    : QWidget(parent)
    , m_plot(new QCustomPlot)

{
    auto* vlayout = new QVBoxLayout(this);
    vlayout->setContentsMargins(0, 0, 0, 0);
    vlayout->setSpacing(0);
    vlayout->setContentsMargins(0, 0, 0, 0);
    vlayout->addWidget(m_plot);
    m_plot->setAttribute(Qt::WA_NoMousePropagation, false);
    setLayout(vlayout);
    setStyleSheet("background-color:white;");

    initGraph();

    m_plot->xAxis->setTickLabelFont(
        QFont(QFont().family(), GUI::Constants::plot_tick_label_size()));
    m_plot->yAxis->setTickLabelFont(
        QFont(QFont().family(), GUI::Constants::plot_tick_label_size()));

    m_plot->yAxis->setScaleType(QCPAxis::stLogarithmic);
    m_plot->yAxis->setNumberFormat("eb");
    m_plot->yAxis->setNumberPrecision(0);

    m_plot->xAxis->setLabel("iteration");
    m_plot->yAxis->setLabel("chi2");

    m_plot->xAxis->setLabelFont(QFont(QFont().family(), GUI::Constants::plot_axes_label_size()));
    m_plot->yAxis->setLabelFont(QFont(QFont().family(), GUI::Constants::plot_axes_label_size()));
}

void HistogramPlot::addData(double x, double y)
{
    m_plot->graph()->addData(x, y);
    m_plot->graph()->rescaleAxes();
    m_plot->replot();
}

void HistogramPlot::addData(const QVector<double>& x, const QVector<double>& y)
{
    m_plot->graph()->addData(x, y);
    m_plot->graph()->rescaleAxes();
    m_plot->replot();
}

void HistogramPlot::setData(const QVector<double>& x, const QVector<double>& y)
{
    m_plot->graph()->setData(x, y);
    m_plot->graph()->rescaleAxes();
    m_plot->replot();
}

void HistogramPlot::clearData()
{
    m_plot->removeGraph(m_plot->graph());
    initGraph();
    m_plot->replot();
}

void HistogramPlot::initGraph()
{
    m_plot->addGraph();

    QPen pen(QColor(0, 0, 255, 200));
    m_plot->graph()->setLineStyle(QCPGraph::lsLine);
    m_plot->graph()->setPen(pen);
    m_plot->graph()->setBrush(QBrush(QColor(255 / 4, 160, 50, 150)));

    auto base_size = GUI::Style::SizeOfLetterM();
    auto* axisRectangle = m_plot->axisRect();
    axisRectangle->setAutoMargins(QCP::msTop | QCP::msBottom);
    axisRectangle->setMargins(QMargins(base_size.width() * 4, base_size.height() * 2,
                                       base_size.width() * 2, base_size.height() * 2));
}
